#!/bin/sh
# $Id: netams-startup.sh,v 1.7 2008-01-03 12:44:53 anton Exp $
# this is FreeBSD version
# for Linux, replace /usr/local/libexec/netams to /usr/local/sbin/netams
# and /usr/local/etc/netams.conf to /etc/netams.conf
daemondir=DAEMONDIR
path_to_etc=PATH_TO_ETC

case "$1" in

start)
        sleep 3;
        /bin/mkdir -p /var/run/netams
        if [ -x $daemondir/netams ]; then
                if [ -f $path_to_etc/netams.conf ]; then
                        $daemondir/netams -lf $path_to_etc/netams.conf >/dev/null && echo -n ' NeTAMS'
                fi
        fi
        ;;

stop)
        killall netams
        rmdir /var/run/netams
        ;;
*)
        echo "$0 start | stop"
        ;;

esac
